You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by ki...@apache.org on 2020/08/26 02:47:43 UTC

[commons-collections] branch master updated (0fbfbfc -> a60636f)

This is an automated email from the ASF dual-hosted git repository.

kinow pushed a change to branch master
in repository https://gitbox.apache.org/repos/asf/commons-collections.git.


    from 0fbfbfc  Merge branch 'pr-176'
     new c9fa433  [COLLECTIONS-764] Refine javadoc and fix typos
     new aa2a29f  [COLLECTIONS-764] changelog
     new a60636f  Merge branch 'pr-165'

The 3 revisions listed above as "new" are entirely new to this
repository and will be described in separate emails.  The revisions
listed as "add" were already present in the repository and have only
been added to this reference.


Summary of changes:
 src/changes/changes.xml                            |  3 ++
 .../java/org/apache/commons/collections4/Bag.java  |  2 +-
 .../org/apache/commons/collections4/MultiSet.java  |  4 +-
 .../org/apache/commons/collections4/Predicate.java |  2 +-
 .../commons/collections4/bag/AbstractMapBag.java   |  2 +-
 .../commons/collections4/bag/CollectionBag.java    |  2 +-
 .../collections4/bag/CollectionSortedBag.java      |  2 +-
 .../commons/collections4/bag/UnmodifiableBag.java  |  2 +-
 .../collections4/bag/UnmodifiableSortedBag.java    |  2 +-
 .../collections4/iterators/CollatingIterator.java  |  6 +--
 .../iterators/ObjectGraphIterator.java             |  2 +-
 .../collections4/map/AbstractHashedMap.java        |  2 +-
 .../collections4/map/AbstractReferenceMap.java     |  2 +-
 .../apache/commons/collections4/map/LRUMap.java    | 10 ++---
 .../multiset/UnmodifiableMultiSet.java             |  2 +-
 .../collections4/queue/CircularFifoQueue.java      |  2 +-
 .../collections4/trie/AbstractPatriciaTrie.java    | 46 ++++++++++------------
 .../commons/collections4/ClosureUtilsTest.java     |  6 +--
 .../commons/collections4/FactoryUtilsTest.java     |  8 ++--
 .../apache/commons/collections4/MapUtilsTest.java  |  4 +-
 .../commons/collections4/PredicateUtilsTest.java   |  8 ++--
 .../commons/collections4/TransformerUtilsTest.java |  4 +-
 .../collections4/bidimap/DualTreeBidiMap2Test.java |  8 ++--
 .../bloomfilter/AbstractBloomFilterTest.java       |  4 +-
 .../bloomfilter/hasher/HasherBuilderTest.java      |  2 +-
 .../comparators/FixedOrderComparatorTest.java      |  4 +-
 .../collections4/functors/AllPredicateTest.java    |  2 +-
 .../iterators/ListIteratorWrapper2Test.java        |  2 +-
 .../iterators/ListIteratorWrapperTest.java         |  2 +-
 .../iterators/NodeListIteratorTest.java            |  2 +-
 .../collections4/list/AbstractListTest.java        | 14 +++----
 .../commons/collections4/map/AbstractMapTest.java  |  4 +-
 .../collections4/map/CaseInsensitiveMapTest.java   |  2 +-
 .../commons/collections4/map/ReferenceMapTest.java | 12 +++---
 .../properties/AbstractPropertiesFactoryTest.java  | 12 +++---
 .../collections4/queue/AbstractQueueTest.java      | 12 +++---
 36 files changed, 102 insertions(+), 103 deletions(-)


[commons-collections] 03/03: Merge branch 'pr-165'

Posted by ki...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

kinow pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/commons-collections.git

commit a60636f5f3dcb9bacdb3ac641e7ef071d7efbb02
Merge: 0fbfbfc aa2a29f
Author: Bruno P. Kinoshita <ki...@apache.org>
AuthorDate: Wed Aug 26 14:47:06 2020 +1200

    Merge branch 'pr-165'
    
    This closes #165

 src/changes/changes.xml                            |  3 ++
 .../java/org/apache/commons/collections4/Bag.java  |  2 +-
 .../org/apache/commons/collections4/MultiSet.java  |  4 +-
 .../org/apache/commons/collections4/Predicate.java |  2 +-
 .../commons/collections4/bag/AbstractMapBag.java   |  2 +-
 .../commons/collections4/bag/CollectionBag.java    |  2 +-
 .../collections4/bag/CollectionSortedBag.java      |  2 +-
 .../commons/collections4/bag/UnmodifiableBag.java  |  2 +-
 .../collections4/bag/UnmodifiableSortedBag.java    |  2 +-
 .../collections4/iterators/CollatingIterator.java  |  6 +--
 .../iterators/ObjectGraphIterator.java             |  2 +-
 .../collections4/map/AbstractHashedMap.java        |  2 +-
 .../collections4/map/AbstractReferenceMap.java     |  2 +-
 .../apache/commons/collections4/map/LRUMap.java    | 10 ++---
 .../multiset/UnmodifiableMultiSet.java             |  2 +-
 .../collections4/queue/CircularFifoQueue.java      |  2 +-
 .../collections4/trie/AbstractPatriciaTrie.java    | 46 ++++++++++------------
 .../commons/collections4/ClosureUtilsTest.java     |  6 +--
 .../commons/collections4/FactoryUtilsTest.java     |  8 ++--
 .../apache/commons/collections4/MapUtilsTest.java  |  4 +-
 .../commons/collections4/PredicateUtilsTest.java   |  8 ++--
 .../commons/collections4/TransformerUtilsTest.java |  4 +-
 .../collections4/bidimap/DualTreeBidiMap2Test.java |  8 ++--
 .../bloomfilter/AbstractBloomFilterTest.java       |  4 +-
 .../bloomfilter/hasher/HasherBuilderTest.java      |  2 +-
 .../comparators/FixedOrderComparatorTest.java      |  4 +-
 .../collections4/functors/AllPredicateTest.java    |  2 +-
 .../iterators/ListIteratorWrapper2Test.java        |  2 +-
 .../iterators/ListIteratorWrapperTest.java         |  2 +-
 .../iterators/NodeListIteratorTest.java            |  2 +-
 .../collections4/list/AbstractListTest.java        | 14 +++----
 .../commons/collections4/map/AbstractMapTest.java  |  4 +-
 .../collections4/map/CaseInsensitiveMapTest.java   |  2 +-
 .../commons/collections4/map/ReferenceMapTest.java | 12 +++---
 .../properties/AbstractPropertiesFactoryTest.java  | 12 +++---
 .../collections4/queue/AbstractQueueTest.java      | 12 +++---
 36 files changed, 102 insertions(+), 103 deletions(-)


[commons-collections] 01/03: [COLLECTIONS-764] Refine javadoc and fix typos

Posted by ki...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

kinow pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/commons-collections.git

commit c9fa43321a953c2b20d472e3b70a04312bfaa5a3
Author: XenoAmess <xe...@gmail.com>
AuthorDate: Tue Jun 2 18:01:25 2020 +0800

    [COLLECTIONS-764] Refine javadoc and fix typos
---
 .../java/org/apache/commons/collections4/Bag.java  |  2 +-
 .../org/apache/commons/collections4/MultiSet.java  |  4 +-
 .../org/apache/commons/collections4/Predicate.java |  2 +-
 .../commons/collections4/bag/AbstractMapBag.java   |  2 +-
 .../commons/collections4/bag/CollectionBag.java    |  2 +-
 .../collections4/bag/CollectionSortedBag.java      |  2 +-
 .../commons/collections4/bag/UnmodifiableBag.java  |  2 +-
 .../collections4/bag/UnmodifiableSortedBag.java    |  2 +-
 .../collections4/iterators/CollatingIterator.java  |  6 +--
 .../iterators/ObjectGraphIterator.java             |  2 +-
 .../collections4/map/AbstractHashedMap.java        |  2 +-
 .../collections4/map/AbstractReferenceMap.java     |  2 +-
 .../apache/commons/collections4/map/LRUMap.java    | 10 ++---
 .../multiset/UnmodifiableMultiSet.java             |  2 +-
 .../collections4/queue/CircularFifoQueue.java      |  2 +-
 .../collections4/trie/AbstractPatriciaTrie.java    | 46 ++++++++++------------
 .../commons/collections4/ClosureUtilsTest.java     |  6 +--
 .../commons/collections4/FactoryUtilsTest.java     |  8 ++--
 .../apache/commons/collections4/MapUtilsTest.java  |  4 +-
 .../commons/collections4/PredicateUtilsTest.java   |  8 ++--
 .../commons/collections4/TransformerUtilsTest.java |  4 +-
 .../collections4/bidimap/DualTreeBidiMap2Test.java |  8 ++--
 .../bloomfilter/AbstractBloomFilterTest.java       |  4 +-
 .../bloomfilter/hasher/HasherBuilderTest.java      |  2 +-
 .../comparators/FixedOrderComparatorTest.java      |  4 +-
 .../collections4/functors/AllPredicateTest.java    |  2 +-
 .../iterators/ListIteratorWrapper2Test.java        |  2 +-
 .../iterators/ListIteratorWrapperTest.java         |  2 +-
 .../iterators/NodeListIteratorTest.java            |  2 +-
 .../collections4/list/AbstractListTest.java        | 14 +++----
 .../commons/collections4/map/AbstractMapTest.java  |  4 +-
 .../collections4/map/CaseInsensitiveMapTest.java   |  2 +-
 .../commons/collections4/map/ReferenceMapTest.java | 12 +++---
 .../properties/AbstractPropertiesFactoryTest.java  | 12 +++---
 .../collections4/queue/AbstractQueueTest.java      | 12 +++---
 35 files changed, 99 insertions(+), 103 deletions(-)

diff --git a/src/main/java/org/apache/commons/collections4/Bag.java b/src/main/java/org/apache/commons/collections4/Bag.java
index 115d4d7..9495d23 100644
--- a/src/main/java/org/apache/commons/collections4/Bag.java
+++ b/src/main/java/org/apache/commons/collections4/Bag.java
@@ -233,7 +233,7 @@ public interface Bag<E> extends Collection<E> {
 //     * Gets a hash code for the Bag compatible with the definition of equals.
 //     * The hash code is defined as the sum total of a hash code for each element.
 //     * The per element hash code is defined as
-//     * {@code (e==null ? 0 : e.hashCode()) ^ noOccurances)}.
+//     * {@code (e==null ? 0 : e.hashCode()) ^ noOccurrences)}.
 //     * This hash code definition is compatible with the Set interface.
 //     *
 //     * @return the hash code of the Bag
diff --git a/src/main/java/org/apache/commons/collections4/MultiSet.java b/src/main/java/org/apache/commons/collections4/MultiSet.java
index bbf9f2d..51dd135 100644
--- a/src/main/java/org/apache/commons/collections4/MultiSet.java
+++ b/src/main/java/org/apache/commons/collections4/MultiSet.java
@@ -204,7 +204,7 @@ public interface MultiSet<E> extends Collection<E> {
      * Gets a hash code for the MultiSet compatible with the definition of equals.
      * The hash code is defined as the sum total of a hash code for each element.
      * The per element hash code is defined as
-     * {@code (e==null ? 0 : e.hashCode()) ^ noOccurances)}.
+     * {@code (e==null ? 0 : e.hashCode()) ^ noOccurrences)}.
      *
      * @return the hash code of the MultiSet
      */
@@ -260,7 +260,7 @@ public interface MultiSet<E> extends Collection<E> {
          * <p>
          * The hash code of a multiset entry {@code e} is defined to be:
          * <pre>
-         *      (e==null ? 0 : e.hashCode()) ^ noOccurances)
+         *      (e==null ? 0 : e.hashCode()) ^ noOccurrences)
          * </pre>
          *
          * @return the hash code value for this multiset entry
diff --git a/src/main/java/org/apache/commons/collections4/Predicate.java b/src/main/java/org/apache/commons/collections4/Predicate.java
index c7af795..5112d2e 100644
--- a/src/main/java/org/apache/commons/collections4/Predicate.java
+++ b/src/main/java/org/apache/commons/collections4/Predicate.java
@@ -27,7 +27,7 @@ package org.apache.commons.collections4;
  * <p>
  * Standard implementations of common predicates are provided by
  * {@link PredicateUtils}. These include true, false, instanceof, equals, and,
- * or, not, method invokation and null testing.
+ * or, not, method invocation and null testing.
  * </p>
  *
  * @param <T> the type that the predicate queries
diff --git a/src/main/java/org/apache/commons/collections4/bag/AbstractMapBag.java b/src/main/java/org/apache/commons/collections4/bag/AbstractMapBag.java
index 8f97088..11e7d9e 100644
--- a/src/main/java/org/apache/commons/collections4/bag/AbstractMapBag.java
+++ b/src/main/java/org/apache/commons/collections4/bag/AbstractMapBag.java
@@ -579,7 +579,7 @@ public abstract class AbstractMapBag<E> implements Bag<E> {
      * Gets a hash code for the Bag compatible with the definition of equals.
      * The hash code is defined as the sum total of a hash code for each
      * element. The per element hash code is defined as
-     * {@code (e==null ? 0 : e.hashCode()) ^ noOccurances)}. This hash code
+     * {@code (e==null ? 0 : e.hashCode()) ^ noOccurrences)}. This hash code
      * is compatible with the Set interface.
      *
      * @return the hash code of the Bag
diff --git a/src/main/java/org/apache/commons/collections4/bag/CollectionBag.java b/src/main/java/org/apache/commons/collections4/bag/CollectionBag.java
index a725823..e01247d 100644
--- a/src/main/java/org/apache/commons/collections4/bag/CollectionBag.java
+++ b/src/main/java/org/apache/commons/collections4/bag/CollectionBag.java
@@ -85,7 +85,7 @@ public final class CollectionBag<E> extends AbstractBagDecorator<E> {
      * @param in  the input stream
      * @throws IOException if an error occurs while reading from the stream
      * @throws ClassNotFoundException if an object read from the stream can not be loaded
-     * @throws ClassCastException if deserialised object has wrong type
+     * @throws ClassCastException if deserialized object has wrong type
      */
     @SuppressWarnings("unchecked") // will throw CCE, see Javadoc
     private void readObject(final ObjectInputStream in) throws IOException, ClassNotFoundException {
diff --git a/src/main/java/org/apache/commons/collections4/bag/CollectionSortedBag.java b/src/main/java/org/apache/commons/collections4/bag/CollectionSortedBag.java
index abcfb3d..50e5753 100644
--- a/src/main/java/org/apache/commons/collections4/bag/CollectionSortedBag.java
+++ b/src/main/java/org/apache/commons/collections4/bag/CollectionSortedBag.java
@@ -76,7 +76,7 @@ public final class CollectionSortedBag<E> extends AbstractSortedBagDecorator<E>
      * @param in  the input stream
      * @throws IOException if an error occurs while reading from the stream
      * @throws ClassNotFoundException if an object read from the stream can not be loaded
-     * @throws ClassCastException if deserialised object has wrong type
+     * @throws ClassCastException if deserialized object has wrong type
      */
     @SuppressWarnings("unchecked") // will throw CCE, see Javadoc
     private void readObject(final ObjectInputStream in) throws IOException, ClassNotFoundException {
diff --git a/src/main/java/org/apache/commons/collections4/bag/UnmodifiableBag.java b/src/main/java/org/apache/commons/collections4/bag/UnmodifiableBag.java
index 6e0f74f..8c3d250 100644
--- a/src/main/java/org/apache/commons/collections4/bag/UnmodifiableBag.java
+++ b/src/main/java/org/apache/commons/collections4/bag/UnmodifiableBag.java
@@ -97,7 +97,7 @@ public final class UnmodifiableBag<E>
      * @param in  the input stream
      * @throws IOException if an error occurs while reading from the stream
      * @throws ClassNotFoundException if an object read from the stream can not be loaded
-     * @throws ClassCastException if deserialised object has wrong type
+     * @throws ClassCastException if deserialized object has wrong type
      */
     @SuppressWarnings("unchecked") // will throw CCE, see Javadoc
     private void readObject(final ObjectInputStream in) throws IOException, ClassNotFoundException {
diff --git a/src/main/java/org/apache/commons/collections4/bag/UnmodifiableSortedBag.java b/src/main/java/org/apache/commons/collections4/bag/UnmodifiableSortedBag.java
index 1e3ecb4..51fad05 100644
--- a/src/main/java/org/apache/commons/collections4/bag/UnmodifiableSortedBag.java
+++ b/src/main/java/org/apache/commons/collections4/bag/UnmodifiableSortedBag.java
@@ -94,7 +94,7 @@ public final class UnmodifiableSortedBag<E>
      * @param in  the input stream
      * @throws IOException if an error occurs while reading from the stream
      * @throws ClassNotFoundException if an object read from the stream can not be loaded
-     * @throws ClassCastException if deserialised object has wrong type
+     * @throws ClassCastException if deserialized object has wrong type
      */
     @SuppressWarnings("unchecked") // will throw CCE, see Javadoc
     private void readObject(final ObjectInputStream in) throws IOException, ClassNotFoundException {
diff --git a/src/main/java/org/apache/commons/collections4/iterators/CollatingIterator.java b/src/main/java/org/apache/commons/collections4/iterators/CollatingIterator.java
index e02ffe7..b2520f8 100644
--- a/src/main/java/org/apache/commons/collections4/iterators/CollatingIterator.java
+++ b/src/main/java/org/apache/commons/collections4/iterators/CollatingIterator.java
@@ -194,7 +194,7 @@ public class CollatingIterator<E> implements Iterator<E> {
     }
 
     /**
-     * Gets the {@link Comparator} by which collatation occurs.
+     * Gets the {@link Comparator} by which collation occurs.
      *
      * @return the {@link Comparator}
      */
@@ -383,8 +383,8 @@ public class CollatingIterator<E> implements Iterator<E> {
      * Returns {@code true} iff any {@link Iterator} in the given list has
      * a next value.
      */
-    private boolean anyHasNext(final List<Iterator<? extends E>> iters) {
-        for (final Iterator<? extends E> iterator : iters) {
+    private boolean anyHasNext(final List<Iterator<? extends E>> iterators) {
+        for (final Iterator<? extends E> iterator : iterators) {
             if (iterator.hasNext()) {
                 return true;
             }
diff --git a/src/main/java/org/apache/commons/collections4/iterators/ObjectGraphIterator.java b/src/main/java/org/apache/commons/collections4/iterators/ObjectGraphIterator.java
index 4ae0c87..3239c61 100644
--- a/src/main/java/org/apache/commons/collections4/iterators/ObjectGraphIterator.java
+++ b/src/main/java/org/apache/commons/collections4/iterators/ObjectGraphIterator.java
@@ -191,7 +191,7 @@ public class ObjectGraphIterator<E> implements Iterator<E> {
             }
             findNext(next);
         }
-        // if we havn't found the next value and iterators are not yet exhausted
+        // if we haven't found the next value and iterators are not yet exhausted
         if (!hasNext && !stack.isEmpty()) {
             // current iterator exhausted, go up a level
             currentIterator = stack.pop();
diff --git a/src/main/java/org/apache/commons/collections4/map/AbstractHashedMap.java b/src/main/java/org/apache/commons/collections4/map/AbstractHashedMap.java
index e291015..ce00054 100644
--- a/src/main/java/org/apache/commons/collections4/map/AbstractHashedMap.java
+++ b/src/main/java/org/apache/commons/collections4/map/AbstractHashedMap.java
@@ -312,7 +312,7 @@ public class AbstractHashedMap<K, V> extends AbstractMap<K, V> implements Iterab
      * uses {@link #put(Object, Object)}.
      * <p>
      * It is private to allow the constructor to still call it
-     * even when putAll is overriden.
+     * even when putAll is overridden.
      *
      * @param map  the map to add
      * @throws NullPointerException if the map is null
diff --git a/src/main/java/org/apache/commons/collections4/map/AbstractReferenceMap.java b/src/main/java/org/apache/commons/collections4/map/AbstractReferenceMap.java
index 139c366..62d398c 100644
--- a/src/main/java/org/apache/commons/collections4/map/AbstractReferenceMap.java
+++ b/src/main/java/org/apache/commons/collections4/map/AbstractReferenceMap.java
@@ -766,7 +766,7 @@ public abstract class AbstractReferenceMap<K, V> extends AbstractHashedMap<K, V>
         }
 
         /**
-         * This method can be overriden to provide custom logic to purge value
+         * This method can be overridden to provide custom logic to purge value
          */
         protected void nullValue() {
             value = null;
diff --git a/src/main/java/org/apache/commons/collections4/map/LRUMap.java b/src/main/java/org/apache/commons/collections4/map/LRUMap.java
index 145ea80..8f10da6 100644
--- a/src/main/java/org/apache/commons/collections4/map/LRUMap.java
+++ b/src/main/java/org/apache/commons/collections4/map/LRUMap.java
@@ -110,7 +110,7 @@ public class LRUMap<K, V>
      * Constructs a new, empty map with the specified maximum size.
      *
      * @param maxSize  the maximum size of the map
-     * @param scanUntilRemovable  scan until a removeable entry is found, default false
+     * @param scanUntilRemovable  scan until a removable entry is found, default false
      * @throws IllegalArgumentException if the maximum size is less than one
      * @since 3.1
      */
@@ -152,7 +152,7 @@ public class LRUMap<K, V>
      *
      * @param maxSize  the maximum size of the map
      * @param loadFactor  the load factor
-     * @param scanUntilRemovable  scan until a removeable entry is found, default false
+     * @param scanUntilRemovable  scan until a removable entry is found, default false
      * @throws IllegalArgumentException if the maximum size is less than one
      * @throws IllegalArgumentException if the load factor is less than zero
      * @since 3.1
@@ -167,7 +167,7 @@ public class LRUMap<K, V>
      * @param maxSize  the maximum size of the map
      * @param initialSize  the initial size of the map
      * @param loadFactor  the load factor
-     * @param scanUntilRemovable  scan until a removeable entry is found, default false
+     * @param scanUntilRemovable  scan until a removable entry is found, default false
      * @throws IllegalArgumentException if the maximum size is less than one
      * @throws IllegalArgumentException if the initial size is negative or larger than the maximum size
      * @throws IllegalArgumentException if the load factor is less than zero
@@ -183,7 +183,7 @@ public class LRUMap<K, V>
             throw new IllegalArgumentException("LRUMap max size must be greater than 0");
         }
         if (initialSize > maxSize) {
-            throw new IllegalArgumentException("LRUMap initial size must not be greather than max size");
+            throw new IllegalArgumentException("LRUMap initial size must not be greater than max size");
         }
         this.maxSize = maxSize;
         this.scanUntilRemovable = scanUntilRemovable;
@@ -208,7 +208,7 @@ public class LRUMap<K, V>
      * <p>The maximum size is set from the map's size.</p>
      *
      * @param map  the map to copy
-     * @param scanUntilRemovable  scan until a removeable entry is found, default false
+     * @param scanUntilRemovable  scan until a removable entry is found, default false
      * @throws NullPointerException if the map is null
      * @throws IllegalArgumentException if the map is empty
      * @since 3.1
diff --git a/src/main/java/org/apache/commons/collections4/multiset/UnmodifiableMultiSet.java b/src/main/java/org/apache/commons/collections4/multiset/UnmodifiableMultiSet.java
index e5c39d1..176a846 100644
--- a/src/main/java/org/apache/commons/collections4/multiset/UnmodifiableMultiSet.java
+++ b/src/main/java/org/apache/commons/collections4/multiset/UnmodifiableMultiSet.java
@@ -93,7 +93,7 @@ public final class UnmodifiableMultiSet<E>
      * @param in  the input stream
      * @throws IOException if an error occurs while reading from the stream
      * @throws ClassNotFoundException if an object read from the stream can not be loaded
-     * @throws ClassCastException if deserialised object has wrong type
+     * @throws ClassCastException if deserialized object has wrong type
      */
     @SuppressWarnings("unchecked") // will throw CCE, see Javadoc
     private void readObject(final ObjectInputStream in) throws IOException, ClassNotFoundException {
diff --git a/src/main/java/org/apache/commons/collections4/queue/CircularFifoQueue.java b/src/main/java/org/apache/commons/collections4/queue/CircularFifoQueue.java
index 88c2689..a912048 100644
--- a/src/main/java/org/apache/commons/collections4/queue/CircularFifoQueue.java
+++ b/src/main/java/org/apache/commons/collections4/queue/CircularFifoQueue.java
@@ -39,7 +39,7 @@ import org.apache.commons.collections4.BoundedCollection;
  * were added.  The iteration order is the same as the removal order.
  * </p>
  * <p>
- * The {@link #add(Object)}, {@link #remove()}, {@link #peek()}, {@link #poll},
+ * The {@link #add(Object)}, {@link #remove()}, {@link #peek()}, {@link #poll()},
  * {@link #offer(Object)} operations all perform in constant time.
  * All other operations perform in linear time or worse.
  * </p>
diff --git a/src/main/java/org/apache/commons/collections4/trie/AbstractPatriciaTrie.java b/src/main/java/org/apache/commons/collections4/trie/AbstractPatriciaTrie.java
index 840d540..50a41bf 100644
--- a/src/main/java/org/apache/commons/collections4/trie/AbstractPatriciaTrie.java
+++ b/src/main/java/org/apache/commons/collections4/trie/AbstractPatriciaTrie.java
@@ -71,8 +71,8 @@ abstract class AbstractPatriciaTrie<K, V> extends AbstractBitwiseTrie<K, V> {
     }
 
     /**
-     * Constructs a new {@link org.apache.commons.collections4.Trie org.apache.commons.collections4.Trie Trie}
-     * using the given {@link KeyAnalyzer} and initializes the {@link org.apache.commons.collections4.Trie Trie}
+     * Constructs a new {@link org.apache.commons.collections4.Trie}
+     * using the given {@link KeyAnalyzer} and initializes the {@link org.apache.commons.collections4.Trie}
      * with the values from the provided {@link Map}.
      */
     protected AbstractPatriciaTrie(final KeyAnalyzer<? super K> keyAnalyzer,
@@ -103,7 +103,7 @@ abstract class AbstractPatriciaTrie<K, V> extends AbstractBitwiseTrie<K, V> {
     }
 
     /**
-     * A helper method to increment the {@link Trie} size and the modification counter.
+     * A helper method to increment the {@link org.apache.commons.collections4.Trie} size and the modification counter.
      */
     void incrementSize() {
         size++;
@@ -111,7 +111,7 @@ abstract class AbstractPatriciaTrie<K, V> extends AbstractBitwiseTrie<K, V> {
     }
 
     /**
-     * A helper method to decrement the {@link Trie} size and increment the modification counter.
+     * A helper method to decrement the {@link org.apache.commons.collections4.Trie} size and increment the modification counter.
      */
     void decrementSize() {
         size--;
@@ -187,7 +187,7 @@ abstract class AbstractPatriciaTrie<K, V> extends AbstractBitwiseTrie<K, V> {
     }
 
     /**
-     * Adds the given {@link TrieEntry} to the {@link Trie}.
+     * Adds the given {@link TrieEntry} to the {@link org.apache.commons.collections4.Trie}.
      */
     TrieEntry<K, V> addEntry(final TrieEntry<K, V> entry, final int lengthInBits) {
         TrieEntry<K, V> current = root.left;
@@ -341,10 +341,6 @@ abstract class AbstractPatriciaTrie<K, V> extends AbstractBitwiseTrie<K, V> {
         return entry.getValue();
     }
 
-    /**
-     * This is equivalent to the other {@link #selectR(TrieEntry, int, Object, int, Cursor, Reference)}
-     * method but without its overhead because we're selecting only one best matching Entry from the {@link Trie}.
-     */
     private boolean selectR(final TrieEntry<K, V> h, final int bitIndex,
                             final K key, final int lengthInBits,
                             final Reference<Map.Entry<K, V>> reference) {
@@ -468,7 +464,7 @@ abstract class AbstractPatriciaTrie<K, V> extends AbstractBitwiseTrie<K, V> {
     }
 
     /**
-     * Removes a single entry from the {@link Trie}.
+     * Removes a single entry from the {@link org.apache.commons.collections4.Trie}.
      *
      * If we found a Key (Entry h) then figure out if it's
      * an internal (hard to remove) or external Entry (easy
@@ -488,7 +484,7 @@ abstract class AbstractPatriciaTrie<K, V> extends AbstractBitwiseTrie<K, V> {
     }
 
     /**
-     * Removes an external entry from the {@link Trie}.
+     * Removes an external entry from the {@link org.apache.commons.collections4.Trie}.
      *
      * If it's an external Entry then just remove it.
      * This is very easy and straight forward.
@@ -519,7 +515,7 @@ abstract class AbstractPatriciaTrie<K, V> extends AbstractBitwiseTrie<K, V> {
     }
 
     /**
-     * Removes an internal entry from the {@link Trie}.
+     * Removes an internal entry from the {@link org.apache.commons.collections4.Trie}.
      *
      * If it's an internal Entry then "good luck" with understanding
      * this code. The Idea is essentially that Entry p takes Entry h's
@@ -734,7 +730,7 @@ abstract class AbstractPatriciaTrie<K, V> extends AbstractBitwiseTrie<K, V> {
     }
 
     /**
-     * Returns the first entry the {@link Trie} is storing.
+     * Returns the first entry the {@link org.apache.commons.collections4.Trie} is storing.
      * <p>
      * This is implemented by going always to the left until
      * we encounter a valid uplink. That uplink is the first key.
@@ -824,14 +820,14 @@ abstract class AbstractPatriciaTrie<K, V> extends AbstractBitwiseTrie<K, V> {
     }
 
     /**
-     * Returns a view of this {@link Trie} of all elements that are prefixed
+     * Returns a view of this {@link org.apache.commons.collections4.Trie} of all elements that are prefixed
      * by the number of bits in the given Key.
      * <p>
      * The view that this returns is optimized to have a very efficient
      * {@link Iterator}. The {@link SortedMap#firstKey()},
      * {@link SortedMap#lastKey()} &amp; {@link Map#size()} methods must
      * iterate over all possible values in order to determine the results.
-     * This information is cached until the PATRICIA {@link Trie} changes.
+     * This information is cached until the PATRICIA {@link org.apache.commons.collections4.Trie} changes.
      * All other methods (except {@link Iterator}) must compare the given
      * key to the prefix to ensure that it is within the range of the view.
      * The {@link Iterator}'s remove method must also relocate the subtree
@@ -841,7 +837,7 @@ abstract class AbstractPatriciaTrie<K, V> extends AbstractBitwiseTrie<K, V> {
      * @param key  the key to use in the search
      * @param offsetInBits  the prefix offset
      * @param lengthInBits  the number of significant prefix bits
-     * @return a {@link SortedMap} view of this {@link Trie} with all elements whose
+     * @return a {@link SortedMap} view of this {@link org.apache.commons.collections4.Trie} with all elements whose
      *   key is prefixed by the search key
      */
     private SortedMap<K, V> getPrefixMapByBits(final K key, final int offsetInBits, final int lengthInBits) {
@@ -1141,7 +1137,7 @@ abstract class AbstractPatriciaTrie<K, V> extends AbstractBitwiseTrie<K, V> {
     }
 
     /**
-     * Returns the last entry the {@link Trie} is storing.
+     * Returns the last entry the {@link org.apache.commons.collections4.Trie} is storing.
      *
      * <p>This is implemented by going always to the right until
      * we encounter a valid uplink. That uplink is the last key.
@@ -1380,7 +1376,7 @@ abstract class AbstractPatriciaTrie<K, V> extends AbstractBitwiseTrie<K, V> {
 
 
     /**
-     * This is a entry set view of the {@link Trie} as returned by {@link Map#entrySet()}.
+     * This is a entry set view of the {@link org.apache.commons.collections4.Trie} as returned by {@link Map#entrySet()}.
      */
     private class EntrySet extends AbstractSet<Map.Entry<K, V>> {
 
@@ -1434,7 +1430,7 @@ abstract class AbstractPatriciaTrie<K, V> extends AbstractBitwiseTrie<K, V> {
     }
 
     /**
-     * This is a key set view of the {@link Trie} as returned by {@link Map#keySet()}.
+     * This is a key set view of the {@link org.apache.commons.collections4.Trie} as returned by {@link Map#keySet()}.
      */
     private class KeySet extends AbstractSet<K> {
 
@@ -1477,7 +1473,7 @@ abstract class AbstractPatriciaTrie<K, V> extends AbstractBitwiseTrie<K, V> {
     }
 
     /**
-     * This is a value view of the {@link Trie} as returned by {@link Map#values()}.
+     * This is a value view of the {@link org.apache.commons.collections4.Trie} as returned by {@link Map#values()}.
      */
     private class Values extends AbstractCollection<V> {
 
@@ -1598,7 +1594,7 @@ abstract class AbstractPatriciaTrie<K, V> extends AbstractBitwiseTrie<K, V> {
     }
 
     /**
-     * An {@link OrderedMapIterator} for a {@link Trie}.
+     * An {@link OrderedMapIterator} for a {@link org.apache.commons.collections4.Trie}.
      */
     private class TrieMapIterator extends TrieIterator<K> implements OrderedMapIterator<K, V> {
 
@@ -1669,7 +1665,7 @@ abstract class AbstractPatriciaTrie<K, V> extends AbstractBitwiseTrie<K, V> {
     }
 
     /**
-     * A range view of the {@link Trie}.
+     * A range view of the {@link org.apache.commons.collections4.Trie}.
      */
     private abstract class RangeMap extends AbstractMap<K, V>
             implements SortedMap<K, V> {
@@ -2077,7 +2073,7 @@ abstract class AbstractPatriciaTrie<K, V> extends AbstractBitwiseTrie<K, V> {
     }
 
     /**
-     * A submap used for prefix views over the {@link Trie}.
+     * A submap used for prefix views over the {@link org.apache.commons.collections4.Trie}.
      */
     private class PrefixRangeMap extends RangeMap {
 
@@ -2108,7 +2104,7 @@ abstract class AbstractPatriciaTrie<K, V> extends AbstractBitwiseTrie<K, V> {
          * This method does two things. It determines the FROM
          * and TO range of the {@link PrefixRangeMap} and the number
          * of elements in the range. This method must be called every
-         * time the {@link Trie} has changed.
+         * time the {@link org.apache.commons.collections4.Trie} has changed.
          */
         private int fixup() {
             // The trie has changed since we last found our toKey / fromKey
@@ -2262,7 +2258,7 @@ abstract class AbstractPatriciaTrie<K, V> extends AbstractBitwiseTrie<K, V> {
     }
 
     /**
-     * A prefix {@link RangeEntrySet} view of the {@link Trie}.
+     * A prefix {@link RangeEntrySet} view of the {@link org.apache.commons.collections4.Trie}.
      */
     private final class PrefixRangeEntrySet extends RangeEntrySet {
 
diff --git a/src/test/java/org/apache/commons/collections4/ClosureUtilsTest.java b/src/test/java/org/apache/commons/collections4/ClosureUtilsTest.java
index 226713b..cca66ab 100644
--- a/src/test/java/org/apache/commons/collections4/ClosureUtilsTest.java
+++ b/src/test/java/org/apache/commons/collections4/ClosureUtilsTest.java
@@ -410,14 +410,14 @@ public class ClosureUtilsTest {
      */
     @Test
     public void testSingletonPatternInSerialization() {
-        final Object[] singletones = new Object[] {
+        final Object[] singletons = new Object[] {
             ExceptionClosure.INSTANCE,
             NOPClosure.INSTANCE,
         };
 
-        for (final Object original : singletones) {
+        for (final Object original : singletons) {
             TestUtils.assertSameAfterSerialization(
-                    "Singletone patern broken for " + original.getClass(),
+                    "Singleton pattern broken for " + original.getClass(),
                     original
             );
         }
diff --git a/src/test/java/org/apache/commons/collections4/MapUtilsTest.java b/src/test/java/org/apache/commons/collections4/MapUtilsTest.java
index 1703bcf..a078976 100644
--- a/src/test/java/org/apache/commons/collections4/MapUtilsTest.java
+++ b/src/test/java/org/apache/commons/collections4/MapUtilsTest.java
@@ -1228,7 +1228,7 @@ public class MapUtilsTest {
         final Map<String, String> in = new HashMap<>();
         in.put("key", "str");
 
-        assertEquals("str", MapUtils.getString(in, "key", "defualt"));
+        assertEquals("str", MapUtils.getString(in, "key", "default"));
         assertEquals("str", MapUtils.getString(in, "key"));
         assertNull(MapUtils.getString(null, "key"));
         assertEquals("default", MapUtils.getString(in, "noKey", "default"));
@@ -1247,7 +1247,7 @@ public class MapUtilsTest {
         final Map<String, Object> in = new HashMap<>();
         in.put("key", "str");
 
-        assertEquals("str", MapUtils.getObject(in, "key", "defualt"));
+        assertEquals("str", MapUtils.getObject(in, "key", "default"));
         assertEquals("str", MapUtils.getObject(in, "key"));
         assertNull(MapUtils.getObject(null, "key"));
         assertEquals("default", MapUtils.getObject(in, "noKey", "default"));
diff --git a/src/test/java/org/apache/commons/collections4/TransformerUtilsTest.java b/src/test/java/org/apache/commons/collections4/TransformerUtilsTest.java
index 196d74c..1c21fdd 100644
--- a/src/test/java/org/apache/commons/collections4/TransformerUtilsTest.java
+++ b/src/test/java/org/apache/commons/collections4/TransformerUtilsTest.java
@@ -478,13 +478,13 @@ public class TransformerUtilsTest {
      */
     @Test
     public void testSingletonPatternInSerialization() {
-        final Object[] singletones = new Object[] {
+        final Object[] singletons = new Object[] {
             ExceptionTransformer.INSTANCE,
             NOPTransformer.INSTANCE,
             StringValueTransformer.stringValueTransformer(),
         };
 
-        for (final Object original : singletones) {
+        for (final Object original : singletons) {
             TestUtils.assertSameAfterSerialization("Singleton pattern broken for " + original.getClass(), original);
         }
     }
diff --git a/src/test/java/org/apache/commons/collections4/bidimap/DualTreeBidiMap2Test.java b/src/test/java/org/apache/commons/collections4/bidimap/DualTreeBidiMap2Test.java
index b7ce7ee..b52cf2d 100644
--- a/src/test/java/org/apache/commons/collections4/bidimap/DualTreeBidiMap2Test.java
+++ b/src/test/java/org/apache/commons/collections4/bidimap/DualTreeBidiMap2Test.java
@@ -115,13 +115,13 @@ public class DualTreeBidiMap2Test<K extends Comparable<K>, V extends Comparable<
 
         final ObjectInputStream in = new ObjectInputStream(new ByteArrayInputStream(buffer.toByteArray()));
         @SuppressWarnings("unchecked")
-        final DualTreeBidiMap<String, Integer> deserialised = (DualTreeBidiMap<String, Integer>) in.readObject();
+        final DualTreeBidiMap<String, Integer> deserialized = (DualTreeBidiMap<String, Integer>) in.readObject();
         in.close();
 
         assertNotNull(original.comparator());
-        assertNotNull(deserialised.comparator());
-        assertEquals(original.comparator().getClass(), deserialised.comparator().getClass());
-        assertEquals(original.valueComparator().getClass(), deserialised.valueComparator().getClass());
+        assertNotNull(deserialized.comparator());
+        assertEquals(original.comparator().getClass(), deserialized.comparator().getClass());
+        assertEquals(original.valueComparator().getClass(), deserialized.valueComparator().getClass());
     }
 
     public void testSortOrder() throws Exception {
diff --git a/src/test/java/org/apache/commons/collections4/bloomfilter/AbstractBloomFilterTest.java b/src/test/java/org/apache/commons/collections4/bloomfilter/AbstractBloomFilterTest.java
index 448add1..b37a5a9 100644
--- a/src/test/java/org/apache/commons/collections4/bloomfilter/AbstractBloomFilterTest.java
+++ b/src/test/java/org/apache/commons/collections4/bloomfilter/AbstractBloomFilterTest.java
@@ -154,7 +154,7 @@ public abstract class AbstractBloomFilterTest {
      * Tests that the andCardinality calculations are correct with a generic BloomFilter.
      */
     @Test
-    public final void andCardinalityTest_GenenicBloomFilter() {
+    public final void andCardinalityTest_GenericBloomFilter() {
         andCardinalityTest(this::createGenericFilter);
     }
 
@@ -544,7 +544,7 @@ public abstract class AbstractBloomFilterTest {
      * Tests that the orCardinality calculations are correct with a generic BloomFilter.
      */
     @Test
-    public final void orCardinalityTest_GenenicBloomFilter() {
+    public final void orCardinalityTest_GenericBloomFilter() {
         orCardinalityTest(this::createGenericFilter);
     }
 
diff --git a/src/test/java/org/apache/commons/collections4/bloomfilter/hasher/HasherBuilderTest.java b/src/test/java/org/apache/commons/collections4/bloomfilter/hasher/HasherBuilderTest.java
index 767b54a..0216075 100644
--- a/src/test/java/org/apache/commons/collections4/bloomfilter/hasher/HasherBuilderTest.java
+++ b/src/test/java/org/apache/commons/collections4/bloomfilter/hasher/HasherBuilderTest.java
@@ -73,7 +73,7 @@ public class HasherBuilderTest {
      * Tests that adding unencoded CharSequence items works correctly.
      */
     @Test
-    public void withUnecodedCharSequenceTest() {
+    public void withUnencodedCharSequenceTest() {
         final String ascii = "plain";
         final String extended = getExtendedString();
         for (final String s : new String[] {ascii, extended}) {
diff --git a/src/test/java/org/apache/commons/collections4/comparators/FixedOrderComparatorTest.java b/src/test/java/org/apache/commons/collections4/comparators/FixedOrderComparatorTest.java
index 97ace60..193569c 100644
--- a/src/test/java/org/apache/commons/collections4/comparators/FixedOrderComparatorTest.java
+++ b/src/test/java/org/apache/commons/collections4/comparators/FixedOrderComparatorTest.java
@@ -87,8 +87,8 @@ public class FixedOrderComparatorTest extends AbstractComparatorTest<String> {
     @Test
     public void testConstructorPlusAdd() {
         final FixedOrderComparator<String> comparator = new FixedOrderComparator<>();
-        for (final String topCitie : topCities) {
-            comparator.add(topCitie);
+        for (final String topCity : topCities) {
+            comparator.add(topCity);
         }
         final String[] keys = topCities.clone();
         assertComparatorYieldsOrder(keys, comparator);
diff --git a/src/test/java/org/apache/commons/collections4/functors/AllPredicateTest.java b/src/test/java/org/apache/commons/collections4/functors/AllPredicateTest.java
index 253df29..56584d8 100644
--- a/src/test/java/org/apache/commons/collections4/functors/AllPredicateTest.java
+++ b/src/test/java/org/apache/commons/collections4/functors/AllPredicateTest.java
@@ -115,7 +115,7 @@ public class AllPredicateTest extends AbstractAnyAllOnePredicateTest<Integer> {
     }
 
     /**
-     * Tests whether combining some true and one false evalutes to false.  Also verifies that only the first
+     * Tests whether combining some true and one false evaluates to false.  Also verifies that only the first
      * false predicate is actually evaluated
      */
     @Test
diff --git a/src/test/java/org/apache/commons/collections4/iterators/ListIteratorWrapper2Test.java b/src/test/java/org/apache/commons/collections4/iterators/ListIteratorWrapper2Test.java
index b5cfbd2..255dbbc 100644
--- a/src/test/java/org/apache/commons/collections4/iterators/ListIteratorWrapper2Test.java
+++ b/src/test/java/org/apache/commons/collections4/iterators/ListIteratorWrapper2Test.java
@@ -192,7 +192,7 @@ public class ListIteratorWrapper2Test<E> extends AbstractIteratorTest<E> {
 
         // after reset, the results should be the same as before
         assertEquals("First element should be the same", first, iter.next());
-        assertEquals("Second elment should be the same", second, iter.next());
+        assertEquals("Second element should be the same", second, iter.next());
 
         // after passing the point, where we resetted, continuation should work as expected
         for (int i = 2; i < testArray.length; i++) {
diff --git a/src/test/java/org/apache/commons/collections4/iterators/ListIteratorWrapperTest.java b/src/test/java/org/apache/commons/collections4/iterators/ListIteratorWrapperTest.java
index a1a1960..fd7e14c 100644
--- a/src/test/java/org/apache/commons/collections4/iterators/ListIteratorWrapperTest.java
+++ b/src/test/java/org/apache/commons/collections4/iterators/ListIteratorWrapperTest.java
@@ -215,7 +215,7 @@ public class ListIteratorWrapperTest<E> extends AbstractIteratorTest<E> {
 
         // after reset, the results should be the same as before
         assertEquals("First element should be the same", first, iter.next());
-        assertEquals("Second elment should be the same", second, iter.next());
+        assertEquals("Second element should be the same", second, iter.next());
 
         // after passing the point, where we resetted, continuation should work as expected
         for (int i = 2; i < testArray.length; i++) {
diff --git a/src/test/java/org/apache/commons/collections4/iterators/NodeListIteratorTest.java b/src/test/java/org/apache/commons/collections4/iterators/NodeListIteratorTest.java
index bde6776..45b9caa 100644
--- a/src/test/java/org/apache/commons/collections4/iterators/NodeListIteratorTest.java
+++ b/src/test/java/org/apache/commons/collections4/iterators/NodeListIteratorTest.java
@@ -34,7 +34,7 @@ public class NodeListIteratorTest extends AbstractIteratorTest<Node> {
     private Node[] nodes;
 
     // NodeListIterator supports two constructors. This flag allows to
-    // control, which constructor to use in makeObject() and makeEmtpyIterator
+    // control, which constructor to use in makeObject() and makeEmptyIterator
     private boolean createIteratorWithStandardConstr = true;
 
     /**
diff --git a/src/test/java/org/apache/commons/collections4/list/AbstractListTest.java b/src/test/java/org/apache/commons/collections4/list/AbstractListTest.java
index 806bf14..bc54cd4 100644
--- a/src/test/java/org/apache/commons/collections4/list/AbstractListTest.java
+++ b/src/test/java/org/apache/commons/collections4/list/AbstractListTest.java
@@ -636,7 +636,7 @@ public abstract class AbstractListTest<E> extends AbstractCollectionTest<E> {
         resetFull();
         try {
             getCollection().set(0, getFullElements()[0]);
-            fail("Emtpy collection should not support set.");
+            fail("Empty collection should not support set.");
         } catch (final UnsupportedOperationException e) {
             // expected
         }
@@ -1044,8 +1044,8 @@ public abstract class AbstractListTest<E> extends AbstractCollectionTest<E> {
             return;
         }
 
-        final byte[] objekt = writeExternalFormToBytes((Serializable) list);
-        final List<E> list2 = (List<E>) readExternalFormFromBytes(objekt);
+        final byte[] object = writeExternalFormToBytes((Serializable) list);
+        final List<E> list2 = (List<E>) readExternalFormFromBytes(object);
 
         assertEquals("Both lists are empty", 0, list.size());
         assertEquals("Both lists are empty", 0, list2.size());
@@ -1059,8 +1059,8 @@ public abstract class AbstractListTest<E> extends AbstractCollectionTest<E> {
             return;
         }
 
-        final byte[] objekt = writeExternalFormToBytes((Serializable) list);
-        final List<E> list2 = (List<E>) readExternalFormFromBytes(objekt);
+        final byte[] object = writeExternalFormToBytes((Serializable) list);
+        final List<E> list2 = (List<E>) readExternalFormFromBytes(object);
 
         assertEquals("Both lists are same size", size, list.size());
         assertEquals("Both lists are same size", size, list2.size());
@@ -1072,7 +1072,7 @@ public abstract class AbstractListTest<E> extends AbstractCollectionTest<E> {
      */
     @SuppressWarnings("unchecked")
     public void testEmptyListCompatibility() throws IOException, ClassNotFoundException {
-        /**
+        /*
          * Create canonical objects with this code
         List list = makeEmptyList();
         if (!(list instanceof Serializable)) return;
@@ -1096,7 +1096,7 @@ public abstract class AbstractListTest<E> extends AbstractCollectionTest<E> {
      */
     @SuppressWarnings("unchecked")
     public void testFullListCompatibility() throws IOException, ClassNotFoundException {
-        /**
+        /*
          * Create canonical objects with this code
         List list = makeFullList();
         if (!(list instanceof Serializable)) return;
diff --git a/src/test/java/org/apache/commons/collections4/map/AbstractMapTest.java b/src/test/java/org/apache/commons/collections4/map/AbstractMapTest.java
index 7214794..029a8d2 100644
--- a/src/test/java/org/apache/commons/collections4/map/AbstractMapTest.java
+++ b/src/test/java/org/apache/commons/collections4/map/AbstractMapTest.java
@@ -750,7 +750,7 @@ public abstract class AbstractMapTest<K, V> extends AbstractObjectTest {
      * against the canonical version in SCM.
      */
     public void testEmptyMapCompatibility() throws Exception {
-        /**
+        /*
          * Create canonical objects with this code
         Map map = makeEmptyMap();
         if (!(map instanceof Serializable)) return;
@@ -772,7 +772,7 @@ public abstract class AbstractMapTest<K, V> extends AbstractObjectTest {
      * against the canonical version in SCM.
      */
     public void testFullMapCompatibility() throws Exception {
-        /**
+        /*
          * Create canonical objects with this code
         Map map = makeFullMap();
         if (!(map instanceof Serializable)) return;
diff --git a/src/test/java/org/apache/commons/collections4/map/CaseInsensitiveMapTest.java b/src/test/java/org/apache/commons/collections4/map/CaseInsensitiveMapTest.java
index d80d01f..5530bc9 100644
--- a/src/test/java/org/apache/commons/collections4/map/CaseInsensitiveMapTest.java
+++ b/src/test/java/org/apache/commons/collections4/map/CaseInsensitiveMapTest.java
@@ -94,7 +94,7 @@ public class CaseInsensitiveMapTest<K, V> extends AbstractIterableMapTest<K, V>
         assertTrue(keys.contains(Integer.toString(20)));
         assertEquals(4, keys.size());
         assertTrue(!caseInsensitiveMap.containsValue("One")
-            || !caseInsensitiveMap.containsValue("Three")); // ones collaped
+            || !caseInsensitiveMap.containsValue("Three")); // ones collapsed
         assertEquals("Four", caseInsensitiveMap.get(null));
     }
 
diff --git a/src/test/java/org/apache/commons/collections4/map/ReferenceMapTest.java b/src/test/java/org/apache/commons/collections4/map/ReferenceMapTest.java
index eff9bc4..865c0ad 100644
--- a/src/test/java/org/apache/commons/collections4/map/ReferenceMapTest.java
+++ b/src/test/java/org/apache/commons/collections4/map/ReferenceMapTest.java
@@ -301,20 +301,20 @@ public class ReferenceMapTest<K, V> extends AbstractIterableMapTest<K, V> {
      */
     public void testDataSizeAfterSerialization() throws IOException, ClassNotFoundException {
 
-        final ReferenceMap<String, String> serialiseMap = new ReferenceMap<>(ReferenceStrength.WEAK, ReferenceStrength.WEAK, true);
-        serialiseMap.put("KEY", "VALUE");
+        final ReferenceMap<String, String> serializeMap = new ReferenceMap<>(ReferenceStrength.WEAK, ReferenceStrength.WEAK, true);
+        serializeMap.put("KEY", "VALUE");
 
         final ByteArrayOutputStream baos = new ByteArrayOutputStream();
         try (ObjectOutputStream out = new ObjectOutputStream(baos)) {
-            out.writeObject(serialiseMap);
+            out.writeObject(serializeMap);
         }
 
         final ByteArrayInputStream bais = new ByteArrayInputStream(baos.toByteArray());
         try (ObjectInputStream in = new ObjectInputStream(bais)) {
             @SuppressWarnings("unchecked")
-            final ReferenceMap<String, String> deserialisedMap = (ReferenceMap<String, String>) in.readObject();
-            assertEquals(1, deserialisedMap.size());
-            assertEquals(serialiseMap.data.length, deserialisedMap.data.length);
+            final ReferenceMap<String, String> deserializedMap = (ReferenceMap<String, String>) in.readObject();
+            assertEquals(1, deserializedMap.size());
+            assertEquals(serializeMap.data.length, deserializedMap.data.length);
         }
 
     }
diff --git a/src/test/java/org/apache/commons/collections4/properties/AbstractPropertiesFactoryTest.java b/src/test/java/org/apache/commons/collections4/properties/AbstractPropertiesFactoryTest.java
index dcdc9ea..3e76c77 100644
--- a/src/test/java/org/apache/commons/collections4/properties/AbstractPropertiesFactoryTest.java
+++ b/src/test/java/org/apache/commons/collections4/properties/AbstractPropertiesFactoryTest.java
@@ -42,13 +42,13 @@ public abstract class AbstractPropertiesFactoryTest<T extends Properties> {
 
     private final AbstractPropertiesFactory<T> factory;
     private final String pathString;
-    private final String fileExtention;
+    private final String fileExtension;
 
     protected AbstractPropertiesFactoryTest(final AbstractPropertiesFactory<T> factory, final String fileExtension) {
         super();
         this.factory = factory;
-        this.fileExtention = fileExtension;
-        this.pathString = BulkTest.TEST_PROPERTIES_PATH + "test" + fileExtention;
+        this.fileExtension = fileExtension;
+        this.pathString = BulkTest.TEST_PROPERTIES_PATH + "test" + fileExtension;
     }
 
     private void assertContents(final T properties) {
@@ -66,7 +66,7 @@ public abstract class AbstractPropertiesFactoryTest<T extends Properties> {
     }
 
     private boolean isXmlTest() {
-        return ".xml".equals(fileExtention);
+        return ".xml".equals(fileExtension);
     }
 
     @Test
@@ -76,12 +76,12 @@ public abstract class AbstractPropertiesFactoryTest<T extends Properties> {
 
     @Test
     public void testLoadClassLoaderMissingResource() throws Exception {
-        Assert.assertNull(factory.load(ClassLoader.getSystemClassLoader(), "missing/test" + fileExtention));
+        Assert.assertNull(factory.load(ClassLoader.getSystemClassLoader(), "missing/test" + fileExtension));
     }
 
     @Test
     public void testLoadClassLoaderResource() throws Exception {
-        assertContents(factory.load(ClassLoader.getSystemClassLoader(), "org/apache/commons/collections4/properties/test" + fileExtention));
+        assertContents(factory.load(ClassLoader.getSystemClassLoader(), "org/apache/commons/collections4/properties/test" + fileExtension));
     }
 
     @Test
diff --git a/src/test/java/org/apache/commons/collections4/queue/AbstractQueueTest.java b/src/test/java/org/apache/commons/collections4/queue/AbstractQueueTest.java
index adf2229..e2eaaab 100644
--- a/src/test/java/org/apache/commons/collections4/queue/AbstractQueueTest.java
+++ b/src/test/java/org/apache/commons/collections4/queue/AbstractQueueTest.java
@@ -313,8 +313,8 @@ public abstract class AbstractQueueTest<E> extends AbstractCollectionTest<E> {
             return;
         }
 
-        final byte[] objekt = writeExternalFormToBytes((Serializable) queue);
-        final Queue<E> queue2 = (Queue<E>) readExternalFormFromBytes(objekt);
+        final byte[] object = writeExternalFormToBytes((Serializable) queue);
+        final Queue<E> queue2 = (Queue<E>) readExternalFormFromBytes(object);
 
         assertEquals("Both queues are empty", 0, queue.size());
         assertEquals("Both queues are empty", 0, queue2.size());
@@ -328,8 +328,8 @@ public abstract class AbstractQueueTest<E> extends AbstractCollectionTest<E> {
             return;
         }
 
-        final byte[] objekt = writeExternalFormToBytes((Serializable) queue);
-        final Queue<E> queue2 = (Queue<E>) readExternalFormFromBytes(objekt);
+        final byte[] object = writeExternalFormToBytes((Serializable) queue);
+        final Queue<E> queue2 = (Queue<E>) readExternalFormFromBytes(object);
 
         assertEquals("Both queues are same size", size, queue.size());
         assertEquals("Both queues are same size", size, queue2.size());
@@ -341,7 +341,7 @@ public abstract class AbstractQueueTest<E> extends AbstractCollectionTest<E> {
      */
     @SuppressWarnings("unchecked")
     public void testEmptyQueueCompatibility() throws IOException, ClassNotFoundException {
-        /**
+        /*
          * Create canonical objects with this code
         Queue queue = makeEmptyQueue();
         if (!(queue instanceof Serializable)) return;
@@ -364,7 +364,7 @@ public abstract class AbstractQueueTest<E> extends AbstractCollectionTest<E> {
      */
     @SuppressWarnings("unchecked")
     public void testFullQueueCompatibility() throws IOException, ClassNotFoundException {
-        /**
+        /*
          * Create canonical objects with this code
         Queue queue = makeFullQueue();
         if (!(queue instanceof Serializable)) return;


[commons-collections] 02/03: [COLLECTIONS-764] changelog

Posted by ki...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

kinow pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/commons-collections.git

commit aa2a29f92d9785577ecbf312a2f3c2dc8847ae81
Author: Bruno P. Kinoshita <ki...@apache.org>
AuthorDate: Wed Aug 26 14:46:57 2020 +1200

    [COLLECTIONS-764] changelog
---
 src/changes/changes.xml | 3 +++
 1 file changed, 3 insertions(+)

diff --git a/src/changes/changes.xml b/src/changes/changes.xml
index d95b354..19010fa 100644
--- a/src/changes/changes.xml
+++ b/src/changes/changes.xml
@@ -21,6 +21,9 @@
   </properties>
   <body>
   <release version="4.5" date="2020-MM-DD" description="Maintenance release.">
+    <action issue="COLLECTIONS-764" dev="kinow" type="fix" due-to="XenoAmess">
+      Refine javadoc and fix typos.
+    </action>
     <action issue="COLLECTIONS-765" dev="kinow" type="fix" due-to="Tobias Kiecker">
       Update Javadoc of ListIteratorWrapper#remove.
     </action>
diff --git a/src/test/java/org/apache/commons/collections4/FactoryUtilsTest.java b/src/test/java/org/apache/commons/collections4/FactoryUtilsTest.java
index b003a94..d57cfa8 100644
--- a/src/test/java/org/apache/commons/collections4/FactoryUtilsTest.java
+++ b/src/test/java/org/apache/commons/collections4/FactoryUtilsTest.java
@@ -256,18 +256,18 @@ public class FactoryUtilsTest {
     //------------------------------------------------------------------
 
     /**
      * Test that all Factory singletones hold singleton pattern in
      * serialization/deserialization process.
      */
     @Test
     public void testSingletonPatternInSerialization() {
-        final Object[] singletones = new Object[] {
+        final Object[] singletons = new Object[] {
             ExceptionFactory.INSTANCE,
         };
 
-        for (final Object original : singletones) {
+        for (final Object original : singletons) {
             TestUtils.assertSameAfterSerialization(
-                    "Singletone patern broken for " + original.getClass(),
+                    "Singleton pattern broken for " + original.getClass(),
                     original
             );
         }
@@ -256,18 +256,18 @@ public class FactoryUtilsTest {
 
     /**
-     * Test that all Factory singletones hold singleton pattern in
+     * Test that all Factory singletons hold singleton pattern in
      * serialization/deserialization process.
      */
diff --git a/src/test/java/org/apache/commons/collections4/PredicateUtilsTest.java b/src/test/java/org/apache/commons/collections4/PredicateUtilsTest.java
index 5cb4971..af558a6 100644
--- a/src/test/java/org/apache/commons/collections4/PredicateUtilsTest.java
+++ b/src/test/java/org/apache/commons/collections4/PredicateUtilsTest.java
@@ -670,12 +670,12 @@ public class PredicateUtilsTest extends AbstractPredicateTest {
     //------------------------------------------------------------------
 
     /**
      * Test that all Predicate singletones hold singleton pattern in
      * serialization/deserialization process.
      */
     @Test
     public void testSingletonPatternInSerialization() {
-        final Object[] singletones = new Object[] {
+        final Object[] singletons = new Object[] {
             ExceptionPredicate.INSTANCE,
             FalsePredicate.INSTANCE,
             NotNullPredicate.INSTANCE,
@@ -683,9 +683,9 @@ public class PredicateUtilsTest extends AbstractPredicateTest {
             TruePredicate.INSTANCE
         };
 
-        for (final Object original : singletones) {
+        for (final Object original : singletons) {
             TestUtils.assertSameAfterSerialization(
-                    "Singletone patern broken for " + original.getClass(),
+                    "Singleton pattern broken for " + original.getClass(),
                     original
             );
         }
@@ -670,12 +670,12 @@ public class PredicateUtilsTest extends AbstractPredicateTest {
 
     /**
-     * Test that all Predicate singletones hold singleton pattern in
+     * Test that all Predicate singletons hold singleton pattern in
      * serialization/deserialization process.
      */